You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@harmony.apache.org by gs...@apache.org on 2008/03/05 22:12:47 UTC

svn commit: r634034 - /harmony/enhanced/drlvm/trunk/vm/port/src/thread/linux/thread_asm_em64t.s

Author: gshimansky
Date: Wed Mar  5 13:12:43 2008
New Revision: 634034

URL: http://svn.apache.org/viewvc?rev=634034&view=rev
Log:
Applied patch from HARMONY-5576
[drlvm][jvmti] breakpoints are broken by r633414 - regression


Modified:
    harmony/enhanced/drlvm/trunk/vm/port/src/thread/linux/thread_asm_em64t.s

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/thread/linux/thread_asm_em64t.s
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/thread/linux/thread_asm_em64t.s?rev=634034&r1=634033&r2=634034&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/thread/linux/thread_asm_em64t.s (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/thread/linux/thread_asm_em64t.s Wed Mar  5 13:12:43 2008
@@ -114,7 +114,7 @@
 .globl port_longjump_stub
 	.type	port_longjump_stub, @function
 port_longjump_stub:
-//    movq    128(%rsp), %rcx // load RCX with the address of saved Registers
-    movq    (%rsp), %rcx // load RCX with the address of saved Registers
+//    movq    128(%rsp), %rdi // load RDI with the address of saved Registers
+    movq    (%rsp), %rdi // load RDI with the address of saved Registers
     callq   port_transfer_to_regs   // restore context
     ret                             // dummy RET - unreachable